from setuptools import setup
from os import path

this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, "README.md"), encoding="utf-8") as f:
    long_description = f.read()

setup(
    name="gopay",
    version="1.2.10",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/gopaycommunity/gopay-python-sdk",
    author="GoPay",
    author_email="integrace@gopay.cz",
    license="MIT",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: Implementation :: PyPy",
    ],
    keywords="gopay payments sdk rest api",
    packages=["gopay"],
    install_requires=["requests", "deprecated>=1.2.0"],
)
